# METASPACE Python client

Python package that provides programmatic access to [METASPACE](https://metaspace2020.eu).

## Applications

* Running batch jobs
* Exploratory analysis of submitted data
* Quick access to things hidden from web interface (such as location of files on S3 and other metadata)

## Installation

You need to have **Python 3.6 or higher** to use this library.

```
pip install metaspace2020
```

## Documentation

The package documentation is available at [metaspace2020.readthedocs.io](https://metaspace2020.readthedocs.io)

## Acknowledgements and license

[See the top-level README](../../README.md#acknowledgements)